@@ -57,7 +57,7 @@ def check_authentication_conf_does_not_have_binddnpassword_property(app, reporte
 
 
 # ACD-2339
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.6.0")
 def check_saml_auth_should_not_turn_off_signed_assertion(app, reporter):
     """Check that saml-* stanzas in `authentication.conf` do not turn off signedAssertion property
@@ -106,7 +106,7 @@ def _is_signed_assertion_off(section):
     return not normalizeBoolean(section.get_option("signedAssertion").value.strip())
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "python3_version")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "python3_version", "private_app")
 @splunk_appinspect.cert_version(min="2.1.0")
 def check_scripted_authentication_has_valid_python_version_property(
     app, reporter, target_splunk_version
