@@ -242,7 +242,7 @@ def check_for_reflected_xss_in_javascript(app, reporter):
             reporter.manual_check(message=result[0])
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "telemetry")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "telemetry", "private_app")
 @splunk_appinspect.cert_version(min="2.2.0")
 def check_telemetry_endpoint_usage_in_javascript(app, reporter):
     """Check that app does not use REST endpoint to collect and send telemetry data."""
@@ -271,7 +271,7 @@ def check_telemetry_endpoint_usage_in_javascript(app, reporter):
         pass
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "telemetry")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "telemetry", "private_app")
 @splunk_appinspect.cert_version(min="2.2.0")
 def check_for_telemetry_metrics_in_javascript(app, reporter):
     """Check for usages of telemetry metrics in JavaScript"""
