@@ -12,7 +12,7 @@ JS files import jquery inside them.
 app: An app object
 reporter: Reporter object """
 
-@splunk_appinspect.tags("cloud", "jquery", "private_app")
+@splunk_appinspect.tags("cloud", "jquery", "private_app", "future")
 @splunk_appinspect.cert_version(min="2.5.0")
 def check_jquery_usage(app, reporter):
     """ Check that the app files are using jQuery. """
@@ -39,7 +39,7 @@ do not have a version attribute OR have the version attribute set to a value oth
 app: An app object
 reporter: Reporter object """
 
-@splunk_appinspect.tags("cloud", "jquery", "private_app")
+@splunk_appinspect.tags("cloud", "jquery", "private_app", "future")
 @splunk_appinspect.cert_version(min="2.5.0")
 def check_simplexml_standards_version(app, reporter):
     """ Check that the dashboards in your app have a valid version attribute.
@@ -76,7 +76,7 @@ have unsupported imports
 app: An app object
 reporter: Reporter object """
 
-@splunk_appinspect.tags("cloud", "jquery", "private_app")
+@splunk_appinspect.tags("cloud", "jquery", "private_app", "future")
 @splunk_appinspect.cert_version(min="2.5.0")
 def check_hotlinking_splunk_web_libraries(app, reporter):
     """ Check that the app files are not importing files directly from the
