@@ -1,8 +1,11 @@
+"""Splunk app image file abstraction resource module"""
+
 from PIL import Image
 from .file_resource import FileResource
 
 
 class ImageResource(FileResource):
+    """store metadata of an image file in app"""
 
     def __init__(self, image_path):
         """This only supports PNG/JPEG/GIF image formats, and will thrown NotImplementedError for non supported formats
@@ -15,7 +18,7 @@ class ImageResource(FileResource):
         return self.meta.size
 
     def is_png(self):
-        return self.meta.format == 'PNG'
+        return self.meta.format == "PNG"
 
     def content_type(self):
         return self.meta.format
