@@ -26,6 +26,7 @@ from . import infra
 
 logger = logging.getLogger(__name__)
 PACKAGING_STANDARDS_TAG = "packaging_standards"
+MAX_CHECK_RETRIES = 2
 
 try:
     import sys
@@ -244,12 +245,18 @@ class Validator(object):
                     application_validation_report.validation_start()
                     self.__emit_event("start_app", self.listeners, app)
 
-                    self.__emit_event("start_package_validation", self.listeners, app)
-                    packaging_results = self.__run_checks(
-                        app, context, self.packaging_groups
-                    )
-                    application_validation_report.results = packaging_results
-                    self.__emit_event("finish_package_validation", self.listeners, app)
+                    application_validation_report.results = []
+                    if PACKAGING_STANDARDS_TAG not in self.args["excluded_tags"]:
+                        self.__emit_event(
+                            "start_package_validation", self.listeners, app
+                        )
+                        packaging_results = self.__run_checks(
+                            app, context, self.packaging_groups
+                        )
+                        application_validation_report.results = packaging_results
+                        self.__emit_event(
+                            "finish_package_validation", self.listeners, app
+                        )
 
                     if application_validation_report.has_invalid_package:
                         # If there are packaging issues, skip the remaining checks.
@@ -297,7 +304,16 @@ class Validator(object):
 
     def __execute_check(self, context, app, check):
         self.__emit_event("start_check", self.listeners, check)
+
+        retries = 0
         reporter = check.run(app, context)
+
+        while reporter.state() == "error" and retries < MAX_CHECK_RETRIES:
+            retries += 1
+            logger.info(f"Retrying check because it produced an error, check_name={check.name}")
+            self.__emit_event("retry_check", self.listeners, check, reporter)
+            reporter = check.run(app, context)
+
         self.__emit_event("finish_check", self.listeners, check, reporter)
         return reporter
 
