@@ -1,7 +1,13 @@
-# Copyright 2018 Splunk Inc. All rights reserved.
+# Copyright 2019 Splunk Inc. All rights reserved.
+
+"""This is a helper module to encapsulate the functionality that represents
+Splunk's workflow action feature.
+"""
+
 
 # Python Standard Libraries
 import logging
+
 # Custom Libraries
 from . import workflow_actions_configuration_file
 
@@ -25,14 +31,16 @@ class WorkFlowActions:
 
     def __init__(self, app):
         self.app = app
-        self.file_path = app.get_filename('default', 'workflow_actions.conf')
+        self.file_path = app.get_filename("default", "workflow_actions.conf")
 
     def configuration_file_exists(self):
-        return self.app.file_exists('default', 'workflow_actions.conf')
+        return self.app.file_exists("default", "workflow_actions.conf")
 
     def get_configuration_file(self):
-        return self.app.get_config('workflow_actions.conf',
-                                   config_file=workflow_actions_configuration_file.WorkflowActionsConfigurationFile())
+        return self.app.get_config(
+            "workflow_actions.conf",
+            config_file=workflow_actions_configuration_file.WorkflowActionsConfigurationFile(),
+        )
 
     def get_workflow_actions(self):
 
